@@ -1,6 +1,6 @@
 package XML::MyXML;
 {
-  $XML::MyXML::VERSION = '0.0993';
+  $XML::MyXML::VERSION = '0.1000';
 }
 # ABSTRACT: A simple-to-use XML module, for parsing and creating XML documents
 
@@ -494,7 +494,7 @@ sub check_xml {
 
 package XML::MyXML::Object;
 {
-  $XML::MyXML::Object::VERSION = '0.0993';
+  $XML::MyXML::Object::VERSION = '0.1000';
 }
 
 use Carp;
@@ -753,7 +753,7 @@ XML::MyXML - A simple-to-use XML module, for parsing and creating XML documents
 
 =head1 VERSION
 
-version 0.0993
+version 0.1000
 
 =head1 SYNOPSIS
 
@@ -769,6 +769,12 @@ version 0.0993
     $obj->simplify is hashref { item => { name => 'Table', price => { usd => '10.00', eur => '8.50' } } }
     $obj->simplify({ internal => 1 }) is hashref { name => 'Table', price => { usd => '10.00', eur => '8.50' } }
 
+=head1 PLEASE USE XML::MyXML::II INSTEAD
+
+B<< *** This module will not be maintained anymore *** Please use XML::MyXML::II instead, which is also contained in this distribution *** >>
+
+It's differences are: better unicode handling.
+
 =head1 EXPORT
 
 tidy_xml, xml_to_object, object_to_xml, simple_to_xml, xml_to_simple, check_xml
